@@ -40,20 +40,24 @@ var searchData=
   ['jobmanager_37',['JobManager',['../servicecom_1_1sun_1_1star_1_1util_1_1JobManager.html',1,'com::sun::star::util']]],
   ['jobmanager_2eidl_38',['JobManager.idl',['../JobManager_8idl.html',1,'']]],
   ['jointype_39',['JoinType',['../structcom_1_1sun_1_1star_1_1rendering_1_1StrokeAttributes.html#af92b960dfbc8558928096e5b2076117c',1,'com::sun::star::rendering::StrokeAttributes']]],
-  ['journal_40',['JOURNAL',['../namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a76c72d9a192bb0601aa1f27013fad3fd',1,'com::sun::star::text::BibliographyDataType::JOURNAL()'],['../namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a76c72d9a192bb0601aa1f27013fad3fd',1,'com::sun::star::text::BibliographyDataField::JOURNAL()']]],
+  ['journal_40',['JOURNAL',['../namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataField.html#a76c72d9a192bb0601aa1f27013fad3fd',1,'com::sun::star::text::BibliographyDataField::JOURNAL()'],['../namespacecom_1_1sun_1_1star_1_1text_1_1BibliographyDataType.html#a76c72d9a192bb0601aa1f27013fad3fd',1,'com::sun::star::text::BibliographyDataType::JOURNAL()']]],
   ['july_41',['JULY',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1Months.html#aae7c7cc5b45c941aade847449d8355a2',1,'com::sun::star::i18n::Months']]],
   ['jumpedit_42',['JumpEdit',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1JumpEdit.html',1,'com::sun::star::text::textfield']]],
   ['jumpedit_2eidl_43',['JumpEdit.idl',['../JumpEdit_8idl.html',1,'']]],
-  ['jumpmark_44',['JumpMark',['../servicecom_1_1sun_1_1star_1_1document_1_1MediaDescriptor.html#a51b2490ba24ae76328c7637f379d8a69',1,'com::sun::star::document::MediaDescriptor']]],
-  ['jumptoendofpage_45',['jumpToEndOfPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a476bbce6722fc804b8a67a6d7c4737cb',1,'com::sun::star::text::XPageCursor']]],
-  ['jumptofirstpage_46',['jumpToFirstPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a35805ada8e62b68af3548c92d9239fc3',1,'com::sun::star::text::XPageCursor']]],
-  ['jumptofurthest_47',['jumpToFurthest',['../interfacecom_1_1sun_1_1star_1_1io_1_1XMarkableStream.html#a0dba23daeafaaf331c5e8cabba583645',1,'com::sun::star::io::XMarkableStream']]],
-  ['jumptolastpage_48',['jumpToLastPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a4f09bc833da25f1b6bdf50c27a707e2e',1,'com::sun::star::text::XPageCursor']]],
-  ['jumptomark_49',['jumpToMark',['../interfacecom_1_1sun_1_1star_1_1io_1_1XMarkableStream.html#a5076d3fa091ca2a5616176f8e89e0e28',1,'com::sun::star::io::XMarkableStream']]],
-  ['jumptonextpage_50',['jumpToNextPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a660dc90441fbc7a6af395112cfd11221',1,'com::sun::star::text::XPageCursor']]],
-  ['jumptopage_51',['jumpToPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a909c766dbfe0e7e3e9c71d60f4ad4a36',1,'com::sun::star::text::XPageCursor']]],
-  ['jumptopreviouspage_52',['jumpToPreviousPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#aaa932a448992229905f5d5c47e91c830',1,'com::sun::star::text::XPageCursor']]],
-  ['jumptostartofpage_53',['jumpToStartOfPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a5c638004a9259895725d2cf920f3a587',1,'com::sun::star::text::XPageCursor']]],
-  ['june_54',['JUNE',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1Months.html#af314dbaf560683281ea205a8e8726e7e',1,'com::sun::star::i18n::Months']]],
-  ['justify_55',['justify',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XTextLayout.html#afa630bace2ac1ee7acc044d589e99eb6',1,'com::sun::star::rendering::XTextLayout']]]
+  ['jumplist_44',['JumpList',['../servicecom_1_1sun_1_1star_1_1system_1_1windows_1_1JumpList.html',1,'com::sun::star::system::windows']]],
+  ['jumplist_2eidl_45',['JumpList.idl',['../JumpList_8idl.html',1,'']]],
+  ['jumplistitem_46',['JumpListItem',['../structcom_1_1sun_1_1star_1_1system_1_1windows_1_1JumpListItem.html',1,'com::sun::star::system::windows']]],
+  ['jumplistitem_2eidl_47',['JumpListItem.idl',['../JumpListItem_8idl.html',1,'']]],
+  ['jumpmark_48',['JumpMark',['../servicecom_1_1sun_1_1star_1_1document_1_1MediaDescriptor.html#a51b2490ba24ae76328c7637f379d8a69',1,'com::sun::star::document::MediaDescriptor']]],
+  ['jumptoendofpage_49',['jumpToEndOfPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a476bbce6722fc804b8a67a6d7c4737cb',1,'com::sun::star::text::XPageCursor']]],
+  ['jumptofirstpage_50',['jumpToFirstPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a35805ada8e62b68af3548c92d9239fc3',1,'com::sun::star::text::XPageCursor']]],
+  ['jumptofurthest_51',['jumpToFurthest',['../interfacecom_1_1sun_1_1star_1_1io_1_1XMarkableStream.html#a0dba23daeafaaf331c5e8cabba583645',1,'com::sun::star::io::XMarkableStream']]],
+  ['jumptolastpage_52',['jumpToLastPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a4f09bc833da25f1b6bdf50c27a707e2e',1,'com::sun::star::text::XPageCursor']]],
+  ['jumptomark_53',['jumpToMark',['../interfacecom_1_1sun_1_1star_1_1io_1_1XMarkableStream.html#a5076d3fa091ca2a5616176f8e89e0e28',1,'com::sun::star::io::XMarkableStream']]],
+  ['jumptonextpage_54',['jumpToNextPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a660dc90441fbc7a6af395112cfd11221',1,'com::sun::star::text::XPageCursor']]],
+  ['jumptopage_55',['jumpToPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a909c766dbfe0e7e3e9c71d60f4ad4a36',1,'com::sun::star::text::XPageCursor']]],
+  ['jumptopreviouspage_56',['jumpToPreviousPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#aaa932a448992229905f5d5c47e91c830',1,'com::sun::star::text::XPageCursor']]],
+  ['jumptostartofpage_57',['jumpToStartOfPage',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPageCursor.html#a5c638004a9259895725d2cf920f3a587',1,'com::sun::star::text::XPageCursor']]],
+  ['june_58',['JUNE',['../namespacecom_1_1sun_1_1star_1_1i18n_1_1Months.html#af314dbaf560683281ea205a8e8726e7e',1,'com::sun::star::i18n::Months']]],
+  ['justify_59',['justify',['../interfacecom_1_1sun_1_1star_1_1rendering_1_1XTextLayout.html#afa630bace2ac1ee7acc044d589e99eb6',1,'com::sun::star::rendering::XTextLayout']]]
 ];
